==> speech-analytic-testing_2.0.1_database.tar.gz: database/mssql/procedures/LaunchAudioConverter.sql <==
SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO
CREATE PROCEDURE [dbo].[LaunchAudioConverter] (
	@VCC VARCHAR(50) = NULL, 
	@APP_PATH VARCHAR(250) = NULL,
	@INPUT_FILE_PATH VARCHAR(250) = NULL, 
	@OUTPUT_FOLDER_PATH VARCHAR(250) = NULL
)
AS
BEGIN
	SET NOCOUNT ON

	-- CREAMOS UNA VARIABLE PARA ARMAR EL COMANDO
	DECLARE @COPY_TO_LOCAL_COMMAND VARCHAR(1000) = NULL
	DECLARE @COPY_TO_ORIGINAL_COMMAND VARCHAR(1000) = NULL
	DECLARE @DIARIZATE_COMMAND VARCHAR(1000) = NULL
	DECLARE @DELETE_FROM_LOCAL_INPUT VARCHAR(1000) = NULL
	DECLARE @DELETE_FROM_LOCAL_OUTPUT VARCHAR(1000) = NULL

	DECLARE @LOCAL_C_INPUT_FOLDER VARCHAR(200) = @APP_PATH + '/input'
	DECLARE @LOCAL_C_OUTPUT_FOLDER VARCHAR(200) = @APP_PATH + '/output'
	DECLARE @INPUT_FILE_NAME VARCHAR(250) = NULL

	--SET @COMMAND = 'C:/diarization/inConcertDiarization/inConcertDiarization.exe -i G:/Ftp_Volcado/Repositorio/diarization/inConcertDiarization/source/input/ENTRANTE.wav -o G:/Ftp_Volcado/Repositorio/diarization/inConcertDiarization/source/output -d 1'
	-- xp_cmdshell 'C:\diarization\inConcertDiarization\inConcertDiarization.exe -i C:\diarization\inConcertDiarization\source\input\ENTRANTE.wav -o C:\diarization\inConcertDiarization\source\output -d 1';
	
	-- CREAMOS UNA CTE PARA SEPARAR LAS PARTES DE LA RUTA DE INPUT
	;WITH CTE_INPUT_SPLIT AS (
		SELECT Value 'VAL', 
				ROW_NUMBER() OVER (ORDER BY (SELECT 1)) 'RN' 
			--FROM STRING_SPLIT('G:/Ftp_Volcado/Repositorio/diarization/inConcertDiarization/source/input/ENTRANTE.wav','/')
			FROM STRING_SPLIT(@INPUT_FILE_PATH, '/')
	)

	-- GUARDAMOS EN VARIABLE EL NOMBRE DEL ARCHIVO INPUT
	SELECT TOP 1 @INPUT_FILE_NAME = [VAL] 
		FROM CTE_INPUT_SPLIT 
		ORDER BY [RN] DESC

	-- COMPIAMOS EL ARCHIVO A LA CARPEA DE INPUT CUANDO LAS RUTAS SON DIFERENTES
	IF @INPUT_FILE_PATH <> (@LOCAL_C_INPUT_FOLDER + '/' + @INPUT_FILE_NAME)
	BEGIN
		-- COPIAMOS EL ARCHIVO INPUT DE LA RUTA RECIBIDA A LA CARPETA INPUT LOCAL
		SET @COPY_TO_LOCAL_COMMAND = 'copy "' + @INPUT_FILE_PATH + '" "' +  @LOCAL_C_INPUT_FOLDER + '/' + @INPUT_FILE_NAME + '" '
		SET @COPY_TO_LOCAL_COMMAND = REPLACE(@COPY_TO_LOCAL_COMMAND, '/', '\')
	
		-- EJECUTAMOS EL COMANDO
		EXEC('xp_cmdshell ''' +  @COPY_TO_LOCAL_COMMAND + '''')
	END
	ELSE
	BEGIN
		SELECT 1
	END

	-- ARMAMOS EL COMANDO QUE MUEVE A LA CARPETA LOCAL Y DIARIZAMOS
	--SET @COMMAND = @APP_PATH + '/inConcertDiarization.exe -i ' + @INPUT_FILE_PATH + ' -o ' + @OUTPUT_FOLDER_PATH + ' -d 1';
	--SET @DIARIZATE_COMMAND = 'cd ' + @LOCAL_C_FOLDER + ' & ' + @APP_PATH + '/inConcertDiarization.exe -i input/' + @INPUT_FILE_NAME + ' -o output '
	SET @DIARIZATE_COMMAND = 'cd ' + @APP_PATH + ' & inConcertDiarization.exe -i input/' + @INPUT_FILE_NAME + ' -o output -d 1'
	
	-- EJECUTAMOS EL COMANDO
	EXEC('xp_cmdshell ''' +  @DIARIZATE_COMMAND + '''')

	-- COMPIAMOS EL ARCHIVO A LA CARPEA DE INPUT CUANDO LAS RUTAS SON DIFERENTES
	IF @INPUT_FILE_PATH <> (@LOCAL_C_INPUT_FOLDER + '/' + @INPUT_FILE_NAME)
	BEGIN
		-- COPIAMOS EL ARCHIVO OUTPUT DE LA RUTA LOCAL A LA CARPETA OUTPUT RECIBIDA
		SET @COPY_TO_ORIGINAL_COMMAND = 'copy "' + @LOCAL_C_OUTPUT_FOLDER + '/' + @INPUT_FILE_NAME + '" "' +  @OUTPUT_FOLDER_PATH + '/' + @INPUT_FILE_NAME + '" '
		SET @COPY_TO_ORIGINAL_COMMAND = REPLACE(@COPY_TO_ORIGINAL_COMMAND, '/', '\')

		-- EJECUTAMOS EL COMANDO
		EXEC('xp_cmdshell ''' +  @COPY_TO_ORIGINAL_COMMAND + '''')

		-- REMOVEMOS LOS ARCHIVOS DE INPUT Y OUTPUT LOCAL
		SET @DELETE_FROM_LOCAL_INPUT = 'del "' + @LOCAL_C_INPUT_FOLDER + '/' + @INPUT_FILE_NAME + '" '
		SET @DELETE_FROM_LOCAL_OUTPUT = 'del "' + @LOCAL_C_OUTPUT_FOLDER + '/' + @INPUT_FILE_NAME + '" '
	
		SET @DELETE_FROM_LOCAL_INPUT = REPLACE(@DELETE_FROM_LOCAL_INPUT, '/', '\')
		SET @DELETE_FROM_LOCAL_OUTPUT = REPLACE(@DELETE_FROM_LOCAL_OUTPUT, '/', '\')
	
		EXEC('xp_cmdshell ''' +  @DELETE_FROM_LOCAL_INPUT + '''')
		EXEC('xp_cmdshell ''' +  @DELETE_FROM_LOCAL_OUTPUT + '''')
	END

	SET NOCOUNT OFF
END
GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS OFF 
GO

GO

==> speech-analytic-testing_2.1.1_database.tar.gz: database/mssql/procedures/LaunchAudioConverter.sql <==
SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO
CREATE PROCEDURE [dbo].[LaunchAudioConverter] (
	@VCC VARCHAR(50) = NULL, 
	@APP_PATH VARCHAR(250) = NULL,
	@INPUT_FILE_PATH VARCHAR(250) = NULL, 
	@OUTPUT_FOLDER_PATH VARCHAR(250) = NULL
)
AS
BEGIN
	SET NOCOUNT ON

	-- ASEGURARSE DE QUE LA CARPETA DE RED DEL FTP ES VISIBLE PARA EL USUARIO DE SISTEMA DE SQL SERVER (TOQUE OL)
	-- EXEC xp_cmdshell 'net use L: \\10.205.31.121\Speech_Analytics$'

	-- CREAMOS UNA VARIABLE PARA ARMAR EL COMANDO
	DECLARE @COPY_TO_LOCAL_COMMAND VARCHAR(1000) = NULL
	DECLARE @COPY_TO_ORIGINAL_COMMAND VARCHAR(1000) = NULL
	DECLARE @DIARIZATE_COMMAND VARCHAR(1000) = NULL
	DECLARE @DELETE_FROM_LOCAL_INPUT VARCHAR(1000) = NULL
	DECLARE @DELETE_FROM_LOCAL_OUTPUT VARCHAR(1000) = NULL

	DECLARE @LOCAL_C_INPUT_FOLDER VARCHAR(200) = @APP_PATH + '/input'
	DECLARE @LOCAL_C_OUTPUT_FOLDER VARCHAR(200) = @APP_PATH + '/output'
	DECLARE @INPUT_FILE_NAME VARCHAR(250) = NULL

	--SET @COMMAND = 'C:/diarization/inConcertDiarization/inConcertDiarization.exe -i G:/Ftp_Volcado/Repositorio/diarization/inConcertDiarization/source/input/ENTRANTE.wav -o G:/Ftp_Volcado/Repositorio/diarization/inConcertDiarization/source/output -d 1'
	-- xp_cmdshell 'C:\diarization\inConcertDiarization\inConcertDiarization.exe -i C:\diarization\inConcertDiarization\source\input\ENTRANTE.wav -o C:\diarization\inConcertDiarization\source\output -d 1';
	
	-- CREAMOS UNA CTE PARA SEPARAR LAS PARTES DE LA RUTA DE INPUT
	;WITH CTE_INPUT_SPLIT AS (
		SELECT Value 'VAL', 
				ROW_NUMBER() OVER (ORDER BY (SELECT 1)) 'RN' 
			--FROM STRING_SPLIT('G:/Ftp_Volcado/Repositorio/diarization/inConcertDiarization/source/input/ENTRANTE.wav','/')
			FROM STRING_SPLIT(@INPUT_FILE_PATH, '/')
	)

	-- GUARDAMOS EN VARIABLE EL NOMBRE DEL ARCHIVO INPUT
	SELECT TOP 1 @INPUT_FILE_NAME = [VAL] 
		FROM CTE_INPUT_SPLIT 
		ORDER BY [RN] DESC

	-- COMPIAMOS EL ARCHIVO A LA CARPEA DE INPUT CUANDO LAS RUTAS SON DIFERENTES
	IF @INPUT_FILE_PATH <> (@LOCAL_C_INPUT_FOLDER + '/' + @INPUT_FILE_NAME)
	BEGIN
		-- COPIAMOS EL ARCHIVO INPUT DE LA RUTA RECIBIDA A LA CARPETA INPUT LOCAL
		SET @COPY_TO_LOCAL_COMMAND = 'copy "' + @INPUT_FILE_PATH + '" "' +  @LOCAL_C_INPUT_FOLDER + '/' + @INPUT_FILE_NAME + '" '
		SET @COPY_TO_LOCAL_COMMAND = REPLACE(@COPY_TO_LOCAL_COMMAND, '/', '\')
	
		-- EJECUTAMOS EL COMANDO
		EXEC('xp_cmdshell ''' +  @COPY_TO_LOCAL_COMMAND + '''')
	END
	ELSE
	BEGIN
		SELECT 1
	END

	-- ARMAMOS EL COMANDO QUE MUEVE A LA CARPETA LOCAL Y DIARIZAMOS
	--SET @COMMAND = @APP_PATH + '/inConcertDiarization.exe -i ' + @INPUT_FILE_PATH + ' -o ' + @OUTPUT_FOLDER_PATH + ' -d 1';
	--SET @DIARIZATE_COMMAND = 'cd ' + @LOCAL_C_FOLDER + ' & ' + @APP_PATH + '/inConcertDiarization.exe -i input/' + @INPUT_FILE_NAME + ' -o output '
	SET @DIARIZATE_COMMAND = 'cd ' + @APP_PATH + ' & inConcertDiarization.exe -i input/' + @INPUT_FILE_NAME + ' -o output -d 1'
	
	-- EJECUTAMOS EL COMANDO
	EXEC('xp_cmdshell ''' +  @DIARIZATE_COMMAND + '''')

	-- COMPIAMOS EL ARCHIVO A LA CARPEA DE INPUT CUANDO LAS RUTAS SON DIFERENTES
	IF @INPUT_FILE_PATH <> (@LOCAL_C_INPUT_FOLDER + '/' + @INPUT_FILE_NAME)
	BEGIN
		-- COPIAMOS EL ARCHIVO OUTPUT DE LA RUTA LOCAL A LA CARPETA OUTPUT RECIBIDA
		SET @COPY_TO_ORIGINAL_COMMAND = 'move "' + @LOCAL_C_OUTPUT_FOLDER + '/' + @INPUT_FILE_NAME + '" "' +  @OUTPUT_FOLDER_PATH + '/' + @INPUT_FILE_NAME + '" '
		SET @COPY_TO_ORIGINAL_COMMAND = REPLACE(@COPY_TO_ORIGINAL_COMMAND, '/', '\')

		-- EJECUTAMOS EL COMANDO
		EXEC('xp_cmdshell ''' +  @COPY_TO_ORIGINAL_COMMAND + '''')

		-- REMOVEMOS LOS ARCHIVOS DE INPUT Y OUTPUT LOCAL
		SET @DELETE_FROM_LOCAL_INPUT = 'del "' + @LOCAL_C_INPUT_FOLDER + '/' + @INPUT_FILE_NAME + '" '
		SET @DELETE_FROM_LOCAL_OUTPUT = 'del "' + @LOCAL_C_OUTPUT_FOLDER + '/' + @INPUT_FILE_NAME + '" '
	
		SET @DELETE_FROM_LOCAL_INPUT = REPLACE(@DELETE_FROM_LOCAL_INPUT, '/', '\')
		SET @DELETE_FROM_LOCAL_OUTPUT = REPLACE(@DELETE_FROM_LOCAL_OUTPUT, '/', '\')
	
		EXEC('xp_cmdshell ''' +  @DELETE_FROM_LOCAL_INPUT + '''')
		--EXEC('xp_cmdshell ''' +  @DELETE_FROM_LOCAL_OUTPUT + '''')
	END

	--EXEC xp_cmdshell 'net use L: /delete /y' -- TOQUE OL DESCARTADO

	SET NOCOUNT OFF
END
GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS OFF 
GO

GO
